spawn_child_singleton

Function spawn_child_singleton 

pub fn spawn_child_singleton(
    ctx: &mut SpendContext,
    parent_coin_id: Bytes32,
    child_inner_puzzle_hash: TreeHash,
) -> Result<ChildLaunchResult, DriverError>
Spawn a child singleton via ephemeral (0-amount) launcher.

The launcher coin is parented by the parent singleton coin. This is used when an action emits a child singleton.