pub struct ActionLayerConfig<S> { /* private fields */ }Expand description
Configuration for building action layer spends.
Generic over the state type S, which must implement proper CLVM traits.
The state should be a proper cons cell (use #[clvm(list)] with #[clvm(rest)] on last field).
Example
ⓘ
// State must be a cons cell
#[derive(Debug, Clone, ToClvm, FromClvm)]
#[clvm(list)]
pub struct MyState {
pub counter: u64,
#[clvm(rest)]
pub data: Bytes32,
}
let config = ActionLayerConfig::<MyState>::new(action_hashes, hint);
let inner_hash = config.inner_puzzle_hash(&state);Implementations
Sourceimpl<S> ActionLayerConfig<S>
impl<S> ActionLayerConfig<S>
Sourcepub fn new(action_hashes: Vec<Bytes32>, hint: Bytes32) -> Self
pub fn new(action_hashes: Vec<Bytes32>, hint: Bytes32) -> Self
Create a new action layer configuration.
Arguments
action_hashes- The curried puzzle hashes for each actionhint- The hint for the default finalizer
Sourcepub fn action_hashes(&self) -> &[Bytes32] ⓘ
pub fn action_hashes(&self) -> &[Bytes32] ⓘ
Get the action hashes
Sourcepub fn merkle_root(&self) -> Bytes32
pub fn merkle_root(&self) -> Bytes32
Get the merkle root of action hashes
Sourcepub fn inner_puzzle_hash(&self, state: &S) -> TreeHash
pub fn inner_puzzle_hash(&self, state: &S) -> TreeHash
Compute the action layer inner puzzle hash for a given state.
This uses:
- DefaultFinalizer2ndCurryArgs for the finalizer hash
- The merkle root of action hashes
- The state tree hash
Sourcepub fn create_action_layer(&self, state: S) -> ActionLayer<S>
pub fn create_action_layer(&self, state: S) -> ActionLayer<S>
Create an ActionLayer instance for spending
Sourcepub fn build_action_spend(
&self,
ctx: &mut SpendContext,
state: S,
action_index: usize,
action_puzzle: NodePtr,
action_solution: NodePtr,
) -> Result<(NodePtr, NodePtr), DriverError>
pub fn build_action_spend( &self, ctx: &mut SpendContext, state: S, action_index: usize, action_puzzle: NodePtr, action_solution: NodePtr, ) -> Result<(NodePtr, NodePtr), DriverError>
Build an action layer spend.
Returns the inner puzzle and solution NodePtrs.
Arguments
ctx- The spend contextstate- The current stateaction_index- Which action to invoke (index into action_hashes)action_puzzle- The curried action puzzle (use PuzzleModule::curry_puzzle)action_solution- The action solution NodePtr